@@ -1,7 +1,8 @@
-from .structures import UserError
 import datetime
 import platform
 import sys
+from contracts import contract
+from .structures import UserError
 
 
 def main():
@@ -10,20 +11,19 @@ def main():
     parser.add_option("--config", help="Location of yaml configuration")
 
     parser.add_option("-s", "--seq", help="Force sequential", default=False,
-                    action='store_true')
+                      action='store_true')
 
     parser.add_option("-v", "--verbose", help="Write status messages",
-                    default=False, action='store_true')
+                      default=False, action='store_true')
                 
     parser.add_option("-V", help="Show git operations",
-                     dest='show_operations',
-                    default=False, action='store_true')
+                      dest='show_operations',
+                      default=False, action='store_true')
     
     parser.add_option("-O", help="Show stdout/stderr of operations",
-                     dest='show_stdout',
-                    default=False, action='store_true')
-    
-    
+                      dest='show_stdout',
+                      default=False, action='store_true')
+        
     parser.add_option("--yaml", help="Write YAML output", default=False,
                     action='store_true')
 
@@ -46,20 +46,29 @@ def main():
             else:
                 found[r.destination] = r 
                 resources.append(r) 
-         
     
     for e in errors:
         print('error: %s' % e)
         
     from .action import Action
+    
     if len(args) == 0:
         msg = 'Please provide command: %s' % (Action.actions.keys()) 
         raise UserError(msg)
     
-    if len(args) > 1:
-        raise Exception('Please provide only one command.')
-    command = args[0]
+    selectors = args[1:]
     
+    if resources and selectors:
+        resources = filter_resources(resources=resources, selectors=selectors)
+        if not resources:
+            msg = ('warning, selectors %s did not select anything' % selectors)
+            raise UserError(msg)
+    
+#     
+#     if len(args) > 1:
+#         raise Exception('Please provide only one command.')
+#     
+    command = args[0]
     
     quiet = False
 
@@ -120,7 +129,9 @@ def main():
             if r.num_modified() > 0 and  r.num_untracked() == 0:
                 r.commit()
     else:
-        raise Exception('Unknown command "%s".' % command)
+        commands = ", ".join(Action.actions.keys())
+        msg = 'Unknown command %r. Use one of: %s' % (command, commands)
+        raise UserError(msg)
         # 
         # def fetch(r):
         #     if r.config['type'] == 'git':
@@ -128,8 +139,29 @@ def main():
         #         res = r.fetch()
         #         if res:  
         #             print "fetched {dir}".format(dir=r)
-        
+    
 
+@contract(resources='list', selectors='list(str)', returns='list')    
+def filter_resources(resources, selectors):
+    """ Selects the resources in the list which match the selectors """
+    def match(resource, selector):
+        if selector in str(resource):
+            return True
+        if selector in resource.destination:
+            return True
+        # print('no %s %s %s' % (resource.destination, resource, selector))
+        return False
+        
+    res = []
+    for r in resources:
+        for s in selectors:
+            if match(r, s):
+                res.append(r)
+                break
+    
+    return res
+    
+    
 if __name__ == '__main__':
     main()
        
